==> instagram_sync-1.1.1.tar.gz: instagram_sync/src/Plugin/APIType/InstagramLogin.php <==
<?php

namespace Drupal\instagram_sync\Plugin\APIType;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Extension\ModuleExtensionList;
use Drupal\Core\Config\Config;
use Drupal\instagram_sync\APITypePluginBase;
use GuzzleHttp\ClientInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation for Instagram login.
 *
 * @APIType(
 *   id = "instagram_login",
 *   label = @Translation("Instagram API with Instagram Login"),
 *   description = @Translation("Plugin to use instagram login API."),
 * )
 */
class InstagramLogin extends APITypePluginBase {

  const INSTAGRAM_SYNC_API_URL = 'https://graph.instagram.com/';

  /**
   * Request service.
   *
   * @var \GuzzleHttp\ClientInterface
   *   Request service variable.
   */
  protected ClientInterface $httpClient;

  /**
   * Config service.
   *
   * @var \Drupal\Core\Config\Config
   *   Config service variable.
   */
  protected Config $config;

  /**
   * Module list service.
   *
   * @var \Drupal\Core\Extension\ModuleExtensionList
   *   Module list service variable.
   */
  protected ModuleExtensionList $moduleList;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('http_client'),
      $container->get('config.factory'),
      $container->get('extension.list.module'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, ClientInterface $httpClient, ConfigFactoryInterface $configFactory, ModuleExtensionList $extensionList) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);

    $this->httpClient = $httpClient;
    $this->config = $configFactory->getEditable('instagram_sync.settings');
    $this->moduleList = $extensionList;
  }

  /**
   * {@inheritdoc}
   */
  public function importMedia(array $params = []): object|null {
    $url = $this->getApiUrl() . $this->config->get('profile_id') . '/media';
    $query = [
      'access_token' => $this->config->get('access_token'),
      'limit' => INSTAGRAM_SYNC_MAX_QUERY_LIMIT,
      'fields' => implode(',', [
        'id',
        'caption',
        'media_type',
        'media_url',
        'timestamp',
        'thumbnail_url',
        'like_count',
        'comments_count',
        'children{id,media_type,media_url,timestamp,children,thumbnail_url}',
      ]),
    ];
    $query += $params;
    $options = [
      'query' => $query,
    ];

    try {
      $result = $this->httpClient->request('GET', $url, $options);
      return json_decode($result->getBody()->getContents());
    }
    catch (\Exception $e) {
      watchdog_exception('error', $e);
    }

    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function getApiUrl(): string {
    return self::INSTAGRAM_SYNC_API_URL . 'v21.0/';
  }

  /**
   * {@inheritdoc}
   */
  public function getProfileData(array $data): array|null {
    $url = $this->getApiUrl() . 'me';

    $options = [
      'query' => [
        'access_token' => $data['access_token'],
      ],
    ];

    try {
      $result = $this->httpClient->request('GET', $url, $options);
      if ($result->getStatusCode() === 200) {
        return json_decode($result->getBody()->getContents(), TRUE);
      }
    }
    catch (\Exception $e) {
      watchdog_exception('error', $e);
    }
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function refreshAccess(array $data): array|null {
    $url = self::INSTAGRAM_SYNC_API_URL . 'refresh_access_token';

    $options = [
      'query' => [
        'grant_type' => 'ig_refresh_token',
        'access_token' => $data['access_token'],
      ],
    ];

    try {
      $result = $this->httpClient->request('GET', $url, $options);
      if ($result->getStatusCode() === 200) {
        $response = json_decode($result->getBody()->getContents(), TRUE);
        if (!empty($response['access_token'])) {
          $this->config->set('access_token', $response['access_token'])->save();
        }

        return $response;
      }
    }
    catch (\Exception $e) {
      watchdog_exception('error', $e);
    }
    return NULL;
  }

}

==> instagram_sync-1.1.2.tar.gz: instagram_sync/src/Plugin/APIType/InstagramLogin.php <==
<?php

namespace Drupal\instagram_sync\Plugin\APIType;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Extension\ModuleExtensionList;
use Drupal\Core\Config\Config;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\instagram_sync\APITypePluginBase;
use GuzzleHttp\ClientInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Logger\LoggerChannelInterface;

/**
 * Plugin implementation for Instagram login.
 *
 * @APIType(
 *   id = "instagram_login",
 *   label = @Translation("Instagram API with Instagram Login"),
 *   description = @Translation("Plugin to use instagram login API."),
 * )
 */
class InstagramLogin extends APITypePluginBase {

  const INSTAGRAM_SYNC_API_URL = 'https://graph.instagram.com/';

  /**
   * Request service.
   *
   * @var \GuzzleHttp\ClientInterface
   *   Request service variable.
   */
  protected ClientInterface $httpClient;

  /**
   * Config service.
   *
   * @var \Drupal\Core\Config\Config
   *   Config service variable.
   */
  protected Config $config;

  /**
   * Module list service.
   *
   * @var \Drupal\Core\Extension\ModuleExtensionList
   *   Module list service variable.
   */
  protected ModuleExtensionList $moduleList;

  /**
   * Logger service.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   *   Logger service variable.
   */
  protected LoggerChannelInterface $logger;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('http_client'),
      $container->get('config.factory'),
      $container->get('extension.list.module'),
      $container->get('logger.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, ClientInterface $httpClient, ConfigFactoryInterface $configFactory, ModuleExtensionList $extensionList, LoggerChannelFactoryInterface $loggerChannelFactory) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);

    $this->httpClient = $httpClient;
    $this->config = $configFactory->getEditable('instagram_sync.settings');
    $this->moduleList = $extensionList;
    $this->logger = $loggerChannelFactory->get('instagram_sync');
  }

  /**
   * {@inheritdoc}
   */
  public function importMedia(array $params = []): object|null {
    $url = $this->getApiUrl() . $this->config->get('profile_id') . '/media';
    $query = [
      'access_token' => $this->config->get('access_token'),
      'limit' => INSTAGRAM_SYNC_MAX_QUERY_LIMIT,
      'fields' => implode(',', [
        'id',
        'caption',
        'media_type',
        'media_url',
        'timestamp',
        'thumbnail_url',
        'like_count',
        'comments_count',
        'children{id,media_type,media_url,timestamp,children,thumbnail_url}',
      ]),
    ];
    $query += $params;
    $options = [
      'query' => $query,
    ];

    try {
      $result = $this->httpClient->request('GET', $url, $options);
      return json_decode($result->getBody()->getContents());
    }
    catch (\Exception $e) {
      $this->logger->error($e->getMessage(), ['exception' => $e]);
    }

    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function getApiUrl(): string {
    return self::INSTAGRAM_SYNC_API_URL . 'v21.0/';
  }

  /**
   * {@inheritdoc}
   */
  public function getProfileData(array $data): array|null {
    $url = $this->getApiUrl() . 'me';

    $options = [
      'query' => [
        'access_token' => $data['access_token'],
      ],
    ];

    try {
      $result = $this->httpClient->request('GET', $url, $options);
      if ($result->getStatusCode() === 200) {
        return json_decode($result->getBody()->getContents(), TRUE);
      }
    }
    catch (\Exception $e) {
      $this->logger->error($e->getMessage(), ['exception' => $e]);
    }
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function refreshAccess(array $data): array|null {
    $url = self::INSTAGRAM_SYNC_API_URL . 'refresh_access_token';

    $options = [
      'query' => [
        'grant_type' => 'ig_refresh_token',
        'access_token' => $data['access_token'],
      ],
    ];

    try {
      $result = $this->httpClient->request('GET', $url, $options);
      if ($result->getStatusCode() === 200) {
        $response = json_decode($result->getBody()->getContents(), TRUE);
        if (!empty($response['access_token'])) {
          $this->config->set('access_token', $response['access_token'])->save();
        }

        return $response;
      }
    }
    catch (\Exception $e) {
      $this->logger->error($e->getMessage(), ['exception' => $e]);
    }
    return NULL;
  }

}
